#
# spec file for package conan
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Note: We only want to build for the default python3
Name:           conan
Version:        2.0.14
Release:        1.1
Summary:        A C/C++ package manager
License:        MIT
URL:            https://conan.io
Source:         https://files.pythonhosted.org/packages/source/c/conan/conan-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
Requires:       python3-Jinja2
Requires:       python3-PyYAML >= 6.0
Requires:       python3-colorama >= 0.4.3
Requires:       python3-distro
Requires:       python3-fasteners >= 0.15
Requires:       python3-patch-ng >= 1.17.4
Requires:       python3-python-dateutil >= 2.8.0
Requires:       python3-requests >= 2.25
Requires:       python3-urllib3 >= 1.26.6
BuildArch:      noarch

%description
Conan is a package manager for C and C++ developers. It is specifically
designed and optimized for accelerating the development and Continuous
Integration of C and C++ projects.

%prep
%autosetup -p1 -n conan-%{version}

%build
%python3_pyproject_wheel

%install
%python3_pyproject_install
%fdupes %{buildroot}%{python3_sitelib}
sed -Ei "1{\@/usr/bin/(env )?python@d}" \
  %{buildroot}%{python3_sitelib}/conan/tools/intel/intel_cc.py \
  %{buildroot}%{python3_sitelib}/conans/test/utils/server_launcher.py

%files
%doc README.md
%license LICENSE.md
%{_bindir}/conan
%{python3_sitelib}/conan/
%{python3_sitelib}/conans/
%{python3_sitelib}/conan-%{version}.dist-info

%changelog
* Sat Dec 16 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.14:
  * Feature: Added riscv64, riscv32 architectures to default
    settings.yml and management of them in Meson and Autotools
    [gh#conan-io/conan#15053].
  * Feature: Allow only one simultaneous database connection
    [gh#conan-io/conan#15029].
  * Feature: Add conan cache backup-upload to upload all the
    backup sources in the cache, regardless of which references
    they are from [gh#conan-io/conan#15013].
  * Feature: New conan list --format=compact for better UX
    [gh#conan-io/conan#15011].
  * Feature: Ignore metadata upload by passing --metadata=""
    [gh#conan-io/conan#15007].
  * Feature: Better output messages in conan upload
    [gh#conan-io/conan#14984].
  * Feature: Add extra flags to CMakeToolchain
    [gh#conan-io/conan#14966].
  * Feature: Implement package load/restore from the cache, for CI
    workflows and moving packages over air-gaps
    [gh#conan-io/conan#14923].
  * Feature: Compute version-ranges intersection to avoid graph
    version conflicts for compatible ranges
    [gh#conan-io/conan#14912].
  * Feature: CMake helper can use multiple targets in target
    argument [gh#conan-io/conan#14883].
  * Feature: Add CMakeDeps and PkgConfigDeps generators listening
    to system_package_version property [gh#conan-io/conan#14808].
  * Feature: Add shorthand syntax in cli to specify host and build
    in 1 argument [gh#conan-io/conan#14727].
  * Feature: Implement cache LRU control for cleaning of unused
    artifacts [gh#conan-io/conan#14054].
  * Fix: Avoid CMakeToolchain overwriting user CMakePresets.json
    when no layout nor output-folder is defined
    [gh#conan-io/conan#15058].
  * Fix: Add astra, elbrus and altlinux as distribution using apt
    in SystemPackageManager [gh#conan-io/conan#15051].
  * Fix: Default to apt-get package manager in Linux Mint
    [gh#conan-io/conan#15026].
  * Fix: Make Git() check commits in remote server even for
    shallow clones [gh#conan-io/conan#15023].
  * Fix: Fix AutotoolsToolchain extraflags priority
    [gh#conan-io/conan#15005].
  * Fix: Remove colors from conan --version output
    [gh#conan-io/conan#15002].
  * Fix: Add an error message if the sqlite3 version is
    unsupported (less than 3.7.11 from 2012)
    [gh#conan-io/conan#14950].
  * Fix: Make cache DB always use forward slash for paths, to be
    uniform across Windows and Linux [gh#conan-io/conan#14940].
  * Fix: Solve re-build of an existing package revision (like
    forcing rebuild of a an existing header-only package), while
    previous folder was still used by other projects
    [gh#conan-io/conan#14938].
  * Fix: Avoid a recipe mutating a conf to affect other recipes
    [gh#conan-io/conan#14932].
  * Fix: The output of system packages via Apt.install() or
    PkgConfig.fill_cpp_info, like xorg/system was very noisy to
    the Conan output, making it more quiet
    [gh#conan-io/conan#14924].
  * Fix: Serialize the path information of python_requires,
    necessary for computing buildinfo [gh#conan-io/conan#14886].
  * Fix: Define remotes in conan source command in case recipe has
    python_requires that need to be downloaded from remotes
    [gh#conan-io/conan#14852].
  * Fix: Fix min target flag for xros and xros-simulator
    [gh#conan-io/conan#14776].
  * Bugfix: --build=missing was doing unnecessary builds of
    packages that were not needed and could be skipped, in the
    case of tool_requires having transitive dependencies
    [gh#conan-io/conan#15082].
  * BugFix: Add package revision to format=json in 'conan
    export-pkg' command [gh#conan-io/conan#15042].
  * Bugfix: tools.build:download_source=True will not fail when
    there are editable packages [gh#conan-io/conan#15004].
  * Bugfix: Transitive dependencies were incorrectly added to
    conandeps.xcconfig [gh#conan-io/conan#14898].
  * Bugfix: Fix integrity-check (upload --check or cache
    check-integrity) when the export_source has not been
    downloaded [gh#conan-io/conan#14850].
  * Bugfix: Properly lock release candidates of python requires
    [gh#conan-io/conan#14846].
  * BugFix: Version ranges ending with - do not automatically
    activate pre-releases resolution in the full range
    [gh#conan-io/conan#14814].
  * BugFix: Fix version ranges so pre-releases are correctly
    included in the lower bound and excluded in the upper bound
    [gh#conan-io/conan#14814].
- New Requires: python-distro.
* Fri Oct 27 2023 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
